@@ -41,17 +41,14 @@ class H5_DLLCPP Attribute : public AbstractDs, public H5Location {
         // Closes this attribute.
         virtual void close();
 
-        // Gets the name of the file, in which this attribute belongs.
-        H5std_string getFileName() const;
-
         // Gets the name of this attribute.
         ssize_t getName(char* attr_name, size_t buf_size = 0) const;
         H5std_string getName(size_t len) const;
         H5std_string getName() const;
         ssize_t getName(H5std_string& attr_name, size_t len = 0) const;
         // The overloaded function below is replaced by the one above and it
-        // is kept for backward compatibility purpose.
-        ssize_t getName(size_t buf_size, H5std_string& attr_name) const;
+        // is kept for backward compatibility purpose.  Removed in 1.8.21.
+        // ssize_t getName(size_t buf_size, H5std_string& attr_name) const;
 
         // Gets a copy of the dataspace for this attribute.
         virtual DataSpace getSpace() const;
@@ -80,6 +77,9 @@ class H5_DLLCPP Attribute : public AbstractDs, public H5Location {
         // Gets the attribute id.
         virtual hid_t getId() const;
 
+        // Throw group exception.
+        virtual void throwException(const H5std_string& func_name, const H5std_string& msg) const;
+
         // Destructor: properly terminates access to this attribute.
         virtual ~Attribute();
 
